#
# spec file for package python-remoto
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-remoto
Version:        1.2.1
Release:        1.9
Summary:        Remote command executor using ssh and Python in the remote end
License:        MIT
URL:            https://github.com/alfredodeza/remoto
Source0:        https://files.pythonhosted.org/packages/source/r/remoto/remoto-%{version}.tar.gz
# https://github.com/alfredodeza/remoto/commit/aa74f65bb59dc46998e72e4bdcd070287e4e2af6
Patch0:         python-remoto-no-mock.patch
BuildRequires:  %{python_module execnet}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module virtualenv}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-execnet
BuildArch:      noarch
# SECTION build requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Remote command executor using ssh and Python in the remote end. This
package is primarily built to support the ceph-deploy project.
python-remoto is built upon python-execnet which manages the
connections and processes.

%prep
%autosetup -p1 -n remoto-%{version}

%build
export REMOTO_NO_VENDOR=no
%python_build

%install
export REMOTO_NO_VENDOR=no
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Fri Apr  8 2022 pgajdos@suse.com
- version update to 1.2.1
  * Prevent deadlock situations by avoiding stderr.read() and stdout.read() in favor of using communicate()
- do not require python-mock for build
- added patches
  fix https://github.com/alfredodeza/remoto/commit/aa74f65bb59dc46998e72e4bdcd070287e4e2af6
  + python-remoto-no-mock.patch
* Mon May 17 2021 Matej Cepl <mcepl@suse.com>
- Remove unnecessary dependency on python-devel.
* Mon Aug  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.2.0
  * Allow to specify python_executable for remote execution, helping
    virtualenvs set remotely.
* Wed Mar 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.5:
  * no changelog found
* Mon May 20 2019 pgajdos@suse.com
- version update to 1.1.4
  * Add needs_ssh to the connection module to fix a backwards
    incompatible change
* Thu Apr 25 2019 pgajdos@suse.com
- version update to 1.1.2
  * Try a few different executables (not only python) to check for
    a working one, in order of preference, starting with python3 and
    ultimately falling back to the connection interpreter
  * Fix an issue with remote Python interpreters that might not be
    python, like in distros that use python3 or similar.
  * Allow to specify --context to kubernetes connections
  * When a remote exception happens using the JsonModuleExecute,
    include both stderr and stdout.
  * Create other connection backends aside from ssh and local:
    kubernetes, podman, docker, and openshift.
  * Adds new remote function/module execution model for non-native
    (for execnet) backends, so that modules will work in backends
    like kubernetes.
  * Create a helper (remoto.connection.get()) for retrieving connection
    backends based on strings
  * Increase the test coverage.
  * Allow using localhost, 127.0.0.1, and 127.0.1.1 to detect local
    connections (before the full hostname was required, as returned by
    socket.gethostname())
  * No longer require creating logging loggers to pass in to connection
    classes, it will create a basic one when undefined.
- turn the test suite on
* Fri Feb  8 2019 ncutler@suse.com
- spec: fix tarball URL
- use official upstream release tarball
* Fri Feb  8 2019 Ricardo Dias <ricardo.dias@suse.com>
- spec: python3-ify
- as of https://github.com/ceph/ceph/pull/26262 this package is a
  runtime dependency of Ceph
- update to 0.0.35:
  + see changelog at https://github.com/alfredodeza/remoto/blob/master/CHANGELOG.rst
* Sun Feb 21 2016 astieger@suse.com
- update to 0.0.27:
  + (releases (0.0.23..27) fix various issues related to stdout/err
  + package a license file (boo#967555)
* Thu Jan 28 2016 ncutler@suse.com
- spec file
  + set Group: to Development/Languages/Python
  + set Source0: to the full URL
* Thu Jan 28 2016 ncutler@suse.com
- Use tarball from pypi.python.org instead of rolling our own from git
- spec file
  + simplify setup
  + remove references to non-existent doc files
* Fri Oct 31 2014 osynge@suse.com
- Updated to 0.0.23
  + Create a better detection mechanism for remote ``sudo`` needs
  + Do not override remote environment variables to set the ``$PATH``
  + Fix unneeded ssh connection when using FQDN hosts
  + Output the exact same order of remote ``stdout`` and ``stderr``
* Mon Jul 21 2014 osynge@suse.com
- Updated to 0.0.19
  + add some imports to init so that they are easier to use
  + make vendor libraries optional
* Mon Jul  7 2014 osynge@suse.com
- Removed embeded python-execnet.
- Removed unneeded dependendcies and build dependencies.
- Replaced summary and description.
- Removed unneeded build enviroment variables.
* Fri Jul  4 2014 osynge@suse.com
- First packaging based upon ceph-deploy-1.5.7
